# Configuration file for the Sphinx documentation builder.
#
# This file only contains a selection of the most common options. For a full
# list see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

# -- Path setup --------------------------------------------------------------

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#
import os
import sys

sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__), '..')))

# -- Project information -----------------------------------------------------

project = html_title = 'Luminaire'
copyright = '2020 Zillow, Inc.'
author = 'Zillow Group A.I. team'

# The full version, including alpha/beta/rc tags
release = '0.1.0'

# -- General configuration ---------------------------------------------------

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = [
    'sphinx.ext.autodoc',
    'sphinx.ext.viewcode',
    'sphinx_material',
]

# Add any paths that contain templates here, relative to this directory.
templates_path = ['_templates']

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This pattern also affects html_static_path and html_extra_path.
exclude_patterns = ['_build', 'Thumbs.db', '.DS_Store']

# -- Options for HTML output -------------------------------------------------
pygments_style = 'friendly'
html_theme = 'sphinx_material'

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ['_static']
html_logo = "assets/luminaire_logo.svg"
html_use_index = True
html_show_sourcelink = False

html_sidebars = {
    "**": ["logo-text.html", "globaltoc.html", "localtoc.html", "searchbox.html"]
}

html_theme_options = {
    'base_url': 'http://zillow.github.io/luminaire/',
    'repo_url': 'https://github.com/zillow/luminaire/',
    'repo_name': 'Fork me on Github',
    'repo_type': 'github',
    'nav_title': 'Luminaire',

    'google_analytics_account': os.environ.get('GA_TRACKING_ID'),
    'html_minify': True,
    'css_minify': True,
    'master_doc': False,  # disables the secondary horizontal "nav bar" which we don't use
    'color_primary': 'custom',
    'color_accent': 'custom',
    'globaltoc_depth': 1,
}
